package it.tref.liferay.mapit.map.hook.deploy;

import it.tref.liferay.mapit.map.model.Plugin;
import it.tref.liferay.mapit.map.service.PluginLocalServiceUtil;
import it.tref.liferay.mapit.map.util.MapItPluginUtil;

import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.plugin.PluginPackage;

public class DeployUtil {

  private final static Log _log = LogFactoryUtil.getLog(DeployUtil.class);

  public static void checkMapItPluginOnDeploy(PluginPackage pluginPackage, ClassLoader contextClassLoader) {

    try {

      String mapItPluginClass = MapItPluginUtil.getMapItPluginClass(contextClassLoader);

      if (MapItPluginUtil.isMapItPlugin(mapItPluginClass, contextClassLoader)) {

        String name = pluginPackage.getName();
        String version = pluginPackage.getVersion();
        String context = pluginPackage.getContext();

        String mapitVersion = MapItPluginUtil.getMapItPluginVersion(contextClassLoader);

        boolean active = MapItPluginUtil.isMapItCompatiblePlugin(mapitVersion);

        MapItPluginUtil.register(context, contextClassLoader, mapItPluginClass);

        Plugin plugin = PluginLocalServiceUtil.getPlugin(context);
        if (plugin == null) {
          PluginLocalServiceUtil.addPlugin(name, version, mapitVersion, context, active);
        } else {
          if (plugin.isActive() && !active) {
            PluginLocalServiceUtil.updatePlugin(plugin.getPluginId(), name, version, mapitVersion, false);
          } else {
            PluginLocalServiceUtil.updatePlugin(plugin.getPluginId(), name, version, mapitVersion, plugin.isActive());
          }
        }
      }
    } catch (SystemException e) {
      _log.error(e, e);
    } catch (Exception e) {
      _log.error(e, e);
    }
  }

  public static void checkMapItPluginOnUndeploy(String context, ClassLoader contextClassLoader) {

    try {

      if (MapItPluginUtil.contains(context)) {

        MapItPluginUtil.unregister(context);

        Plugin plugin = PluginLocalServiceUtil.getPlugin(context);
        if (plugin != null) {
          PluginLocalServiceUtil.deletePlugin(plugin);
        }
      }
    } catch (SystemException e) {
      _log.error(e, e);
    }
  }

}
